@@ -3,7 +3,9 @@ import math
 from binsdpy.utils import operational_taxonomic_units, BinaryFeatureVector
 
 
-def sokal_sneath4(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
+def sokal_sneath4(
+    x: BinaryFeatureVector, y: BinaryFeatureVector, mask: BinaryFeatureVector = None
+) -> float:
     """Sokal-Sneath similarity (v4)
 
     Sneath, P. H., & Sokal, R. R. (1973).
@@ -17,12 +19,14 @@ def sokal_sneath4(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
     Returns:
         float: similarity of given vectors
     """
-    a, b, c, d = operational_taxonomic_units(x, y)
+    a, b, c, d = operational_taxonomic_units(x, y, mask)
 
     return (a / (a + b) + a / (a + c) + d / (b + d) + d / (c + d)) / 4
 
 
-def sokal_sneath5(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
+def sokal_sneath5(
+    x: BinaryFeatureVector, y: BinaryFeatureVector, mask: BinaryFeatureVector = None
+) -> float:
     """Sokal-Sneath similarity (v5)
 
     Sneath, P. H., & Sokal, R. R. (1973).
@@ -36,12 +40,14 @@ def sokal_sneath5(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
     Returns:
         float: similarity of given vectors
     """
-    a, b, c, d = operational_taxonomic_units(x, y)
+    a, b, c, d = operational_taxonomic_units(x, y, mask)
 
     return (a * d) / math.sqrt((a + b) * (a + c) * (b + d) * (c + d))
 
 
-def rogot_goldberg(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
+def rogot_goldberg(
+    x: BinaryFeatureVector, y: BinaryFeatureVector, mask: BinaryFeatureVector = None
+) -> float:
     """Rogot-Goldberg
 
     Rogot, E., & Goldberg, I. D. (1966).
@@ -55,12 +61,14 @@ def rogot_goldberg(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
     Returns:
         float: similarity of given vectors
     """
-    a, b, c, d = operational_taxonomic_units(x, y)
+    a, b, c, d = operational_taxonomic_units(x, y, mask)
 
     return (a / (2 * a + b + c)) + (d / (2 * d + b + c))
 
 
-def baroni_urbani_buser1(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
+def baroni_urbani_buser1(
+    x: BinaryFeatureVector, y: BinaryFeatureVector, mask: BinaryFeatureVector = None
+) -> float:
     """Baroni-Urbani similarity (v1)
 
     Baroni-Urbani, C., & Buser, M. W. (1976).
@@ -74,12 +82,14 @@ def baroni_urbani_buser1(x: BinaryFeatureVector, y: BinaryFeatureVector) -> floa
     Returns:
         float: similarity of given vectors
     """
-    a, b, c, d = operational_taxonomic_units(x, y)
+    a, b, c, d = operational_taxonomic_units(x, y, mask)
 
     return (math.sqrt(a * d) + a) / (math.sqrt(a * d) + a + b + c)
 
 
-def peirce3(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
+def peirce3(
+    x: BinaryFeatureVector, y: BinaryFeatureVector, mask: BinaryFeatureVector = None
+) -> float:
     """Peirce similarity (v3)
 
     Peirce, C. S. (1884).
@@ -93,12 +103,14 @@ def peirce3(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
     Returns:
         float: similarity of given vectors
     """
-    a, b, c, d = operational_taxonomic_units(x, y)
+    a, b, c, d = operational_taxonomic_units(x, y, mask)
 
     return (a * b + b * c) / (a * b + 2 * b * c + c * d)
 
 
-def hawkins_dotson(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
+def hawkins_dotson(
+    x: BinaryFeatureVector, y: BinaryFeatureVector, mask: BinaryFeatureVector = None
+) -> float:
     """Hawkins-Dotson
 
     Hawkins, R. P., & Dotson, V. A. (1973).
@@ -111,12 +123,14 @@ def hawkins_dotson(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
     Returns:
         float: similarity of given vectors
     """
-    a, b, c, d = operational_taxonomic_units(x, y)
+    a, b, c, d = operational_taxonomic_units(x, y, mask)
 
     return .5 * ((a / (a + b + c) + (d / (b + c + d))))
 
 
-def tarantula(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
+def tarantula(
+    x: BinaryFeatureVector, y: BinaryFeatureVector, mask: BinaryFeatureVector = None
+) -> float:
     """Tarantula similarity
 
     Jones, J. A., & Harrold, M. J. (2005, November).
@@ -130,12 +144,14 @@ def tarantula(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
     Returns:
         float: similarity of given vectors
     """
-    a, b, c, d = operational_taxonomic_units(x, y)
+    a, b, c, d = operational_taxonomic_units(x, y, mask)
 
     return (a * (c + d)) / (c * (a + b))
 
 
-def harris_lahey(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
+def harris_lahey(
+    x: BinaryFeatureVector, y: BinaryFeatureVector, mask: BinaryFeatureVector = None
+) -> float:
     """Harris-Lahey similarity
 
     Harris, F. C., & Lahey, B. B. (1978).
@@ -149,14 +165,16 @@ def harris_lahey(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
     Returns:
         float: similarity of given vectors
     """
-    a, b, c, d = operational_taxonomic_units(x, y)
+    a, b, c, d = operational_taxonomic_units(x, y, mask)
 
     return ((a * (2 * d + b + c)) / (2 * (a + b + c))) + (
         (d * (2 * a + b + c) / (2 * (b + c + d)))
     )
 
 
-def forbes1(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
+def forbes1(
+    x: BinaryFeatureVector, y: BinaryFeatureVector, mask: BinaryFeatureVector = None
+) -> float:
     """Forbesi similarity (v1)
 
     Forbes, S. A. (1907).
@@ -174,14 +192,16 @@ def forbes1(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
     Returns:
         float: similarity of given vectors
     """
-    a, b, c, d = operational_taxonomic_units(x, y)
+    a, b, c, d = operational_taxonomic_units(x, y, mask)
 
     n = a + b + c + d
 
     return (n * a) / ((a + b) * (a + c))
 
 
-def baroni_urbani_buser2(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
+def baroni_urbani_buser2(
+    x: BinaryFeatureVector, y: BinaryFeatureVector, mask: BinaryFeatureVector = None
+) -> float:
     """Baroni-Urbani similarity (v1)
 
     Baroni-Urbani, C., & Buser, M. W. (1976).
@@ -195,12 +215,14 @@ def baroni_urbani_buser2(x: BinaryFeatureVector, y: BinaryFeatureVector) -> floa
     Returns:
         float: similarity of given vectors
     """
-    a, b, c, d = operational_taxonomic_units(x, y)
+    a, b, c, d = operational_taxonomic_units(x, y, mask)
 
     return (math.sqrt(a * d) + a - b - c) / (math.sqrt(a * d) + a + b + c)
 
 
-def fossum(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
+def fossum(
+    x: BinaryFeatureVector, y: BinaryFeatureVector, mask: BinaryFeatureVector = None
+) -> float:
     """Fossum similarity
 
     Holliday, J. D., Hu, C. Y., & Willett, P. (2002).
@@ -214,14 +236,16 @@ def fossum(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
     Returns:
         float: similarity of given vectors
     """
-    a, b, c, d = operational_taxonomic_units(x, y)
+    a, b, c, d = operational_taxonomic_units(x, y, mask)
 
     n = a + b + c + d
 
     return (n * (a - 0.5) ** 2) / math.sqrt((a + b) * (a + c))
 
 
-def forbes2(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
+def forbes2(
+    x: BinaryFeatureVector, y: BinaryFeatureVector, mask: BinaryFeatureVector = None
+) -> float:
     """Forbesi similarity (v2)
 
     Forbes, S. A. (1907).
@@ -239,14 +263,16 @@ def forbes2(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
     Returns:
         float: similarity of given vectors
     """
-    a, b, c, d = operational_taxonomic_units(x, y)
+    a, b, c, d = operational_taxonomic_units(x, y, mask)
 
     n = a + b + c + d
 
     return (n * a - (a + b) * (a + c)) / (n * min(a + b, a + c) - (a + b) * (a + c))
 
 
-def eyraud(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
+def eyraud(
+    x: BinaryFeatureVector, y: BinaryFeatureVector, mask: BinaryFeatureVector = None
+) -> float:
     """Eyraud similarity
 
     Eyraud, H. (1936).
@@ -260,7 +286,7 @@ def eyraud(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
     Returns:
         float: similarity of given vectors
     """
-    a, b, c, d = operational_taxonomic_units(x, y)
+    a, b, c, d = operational_taxonomic_units(x, y, mask)
 
     n = a + b + c + d
 
@@ -269,7 +295,9 @@ def eyraud(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
     )
 
 
-def tarwid(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
+def tarwid(
+    x: BinaryFeatureVector, y: BinaryFeatureVector, mask: BinaryFeatureVector = None
+) -> float:
     """Tarwid similarity
 
     Tarwid, K. (1960).
@@ -283,14 +311,16 @@ def tarwid(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
     Returns:
         float: similarity of given vectors
     """
-    a, b, c, d = operational_taxonomic_units(x, y)
+    a, b, c, d = operational_taxonomic_units(x, y, mask)
 
     n = a + b + c + d
 
     return (n * a - (a + b) * (a + c)) / (n * a + (a + b) * (a + c))
 
 
-def goodman_kruskal1(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
+def goodman_kruskal1(
+    x: BinaryFeatureVector, y: BinaryFeatureVector, mask: BinaryFeatureVector = None
+) -> float:
     """Goodman-Kruskal similarity (v1)
 
     Goodman, L. A., & Kruskal, W. H. (1979).
@@ -304,7 +334,7 @@ def goodman_kruskal1(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
     Returns:
         float: similarity of given vectors
     """
-    a, b, c, d = operational_taxonomic_units(x, y)
+    a, b, c, d = operational_taxonomic_units(x, y, mask)
 
     n = a + b + c + d
 
@@ -314,7 +344,9 @@ def goodman_kruskal1(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
     return (p1 - p2) / (2 * n - p2)
 
 
-def anderberg(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
+def anderberg(
+    x: BinaryFeatureVector, y: BinaryFeatureVector, mask: BinaryFeatureVector = None
+) -> float:
     """Anderberg similarity
 
     Anderberg, M. R. (2014).
@@ -328,7 +360,7 @@ def anderberg(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
     Returns:
         float: similarity of given vectors
     """
-    a, b, c, d = operational_taxonomic_units(x, y)
+    a, b, c, d = operational_taxonomic_units(x, y, mask)
 
     n = a + b + c + d
 
@@ -338,7 +370,9 @@ def anderberg(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
     return (p1 - p2) / (2 * n)
 
 
-def goodman_kruskal2(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
+def goodman_kruskal2(
+    x: BinaryFeatureVector, y: BinaryFeatureVector, mask: BinaryFeatureVector = None
+) -> float:
     """Goodman-Kruskal similarity (v2)
 
     Goodman, L. A., & Kruskal, W. H. (1979).
@@ -352,12 +386,14 @@ def goodman_kruskal2(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
     Returns:
         float: similarity of given vectors
     """
-    a, b, c, d = operational_taxonomic_units(x, y)
+    a, b, c, d = operational_taxonomic_units(x, y, mask)
 
     return (2 * min(a, d) - b - c) / (2 * min(a, d) + b + c)
 
 
-def gilbert_wells(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
+def gilbert_wells(
+    x: BinaryFeatureVector, y: BinaryFeatureVector, mask: BinaryFeatureVector = None
+) -> float:
     """Gilbert-Wells similarity
 
     Gilbert, G. K. (1884).
@@ -371,14 +407,16 @@ def gilbert_wells(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
     Returns:
         float: similarity of given vectors
     """
-    a, b, c, d = operational_taxonomic_units(x, y)
+    a, b, c, d = operational_taxonomic_units(x, y, mask)
 
     n = a + b + c + d
 
     return math.log(a) - math.log(n) - math.log((a + b) / n) - math.log((a + c) / n)
 
 
-def consonni_todeschini2(x: BinaryFeatureVector, y: BinaryFeatureVector) -> float:
+def consonni_todeschini2(
+    x: BinaryFeatureVector, y: BinaryFeatureVector, mask: BinaryFeatureVector = None
+) -> float:
     """Consonni and Todeschini (v2)
 
     Consonni, V., & Todeschini, R. (2012).
@@ -392,7 +430,7 @@ def consonni_todeschini2(x: BinaryFeatureVector, y: BinaryFeatureVector) -> floa
     Returns:
         float: similarity of given vectors
     """
-    a, b, c, d = operational_taxonomic_units(x, y)
+    a, b, c, d = operational_taxonomic_units(x, y, mask)
 
     n = a + b + c + d
 
